%define _prefix /usr/local
%define _exec_prefix %{_prefix}
%define _datadir %{prefix}/share

%define _includedir %{_prefix}/include
%define _lib lib
%define _lib64 lib64
%define _libdir %{_exec_prefix}/%{_lib}
%define _datadir %{_prefix}/share
%define _docdir %{_datadir}/doc
%define _bindir %{_exec_prefix}/bin
%define _sbindir %{_exec_prefix}/sbin
%define _mandir %{_prefix}/man
%define _sysconfdir %{_prefix}/etc
%define _localstatedir %{_prefix}/var

%define __perl /usr/local/bin/perl

%define apuver 1

Summary: Apache Portable Runtime Utility library
Name: upenn-apr-util
Version: 1.4.1
Release: 18%{?dist}
License: Apache Software License 2.0
Group: System Environment/Libraries
URL: http://apr.apache.org/
Source0: apr-util-%{version}.tar.gz
Patch1: apr-util-1.2.7-pkgconf.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires: autoconf, doxygen, upenn-apr-devel >= 1.3.0
BuildRequires: db4-devel, expat-devel
BuildRequires: upenn-postgresql
BuildRequires: e2fsprogs-devel

%description
The mission of the Apache Portable Runtime (APR) is to provide a
free library of C data structures and routines.  This library
contains additional utility interfaces for APR; including support
for XML, LDAP, database interfaces, URI parsing and more.

%package devel
Group: Development/Libraries
Summary: APR utility library development kit
Requires: upenn-apr-util = %{version}-%{release}, upenn-apr-devel, pkgconfig
Requires: db4-devel, expat-devel

%description devel
This package provides the support files which can be used to 
build applications using the APR utility library.  The mission 
of the Apache Portable Runtime (APR) is to provide a free 
library of C data structures and routines.

%package docs
Group: Development/Documentation
Summary: Documentation for the Apache Portable Runtime Utility library

%description docs
This package provides documentation for the Apache Portable Runtime Utility 
library. The mission of the Apache Portable Runtime (APR) is to provide a
free library of C data structures and routines.

%package pgsql
Group: Development/Libraries
Summary: APR utility library postgresql DBD driver
BuildRequires: upenn-postgresql
Requires: upenn-apr-util = %{version}-%{release}

%description pgsql
This package provides the postgresql driver for the upenn-apr-util DBD
(database abstraction) interface.

%prep
%setup -q -n apr-util-%{version}
%patch1 -p1 -b .pkgconf

%build
autoheader && autoconf
export CFLAGS="-R/usr/local/var/postgres/9.0"
%configure --with-apr=%{_prefix} \
        --includedir=%{_includedir}/apr-%{apuver} \
        --with-expat=%{_prefix} \
        --with-pgsql=/usr/local/var/postgres/9.0 \
	--without-gdbm \
        --without-berkeley-db \
        --without-sqlite3 \
        --without-sqlite2 \
        --enable-dbd-dso
make %{?_smp_mflags} && make dox
%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Documentation
mv docs/dox/html html

# Unpackaged files; remove the static libaprutil
rm -f $RPM_BUILD_ROOT%{_libdir}/aprutil.exp \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.a

# And remove the reference to the static libaprutil from the .la
# file.
sed -i '/^old_library/s,libapr.*\.a,,' \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.la

# Remove unnecessary exports from dependency_libs
sed -ri '/^dependency_libs/{s,-l(pq|sqlite[0-9]|rt|dl|uuid) ,,g}' \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.la

# Trim libtool DSO cruft
rm -f $RPM_BUILD_ROOT%{_libdir}/apr-util-%{apuver}/*.*a

%check
# Run the less verbose test suites
export MALLOC_CHECK_=2 MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
# Pick up DBD DSOs
export LD_LIBRARY_PATH=$PWD/dbd/.libs
# We don't test dbm / buckets or xml.
# Make sure no old versions of librarys are in /usr/local/lib or /usr/lib /usr/lib64
# This can make tests fail mysteriously on good builds or possibly test could pass on a
# borked build.  
# I test apr is in /usr/local and expat is in /usr/lib* as a precaution.  If tests fail,
# you may want to examine 'ldd testall' output for other problems.
( cd test && make all )
if ! ldd test/testall | perl -lane 'print $F[2] if ($F[2] =~ m{^/usr/local});' | grep apr; then \
	echo "testall is not linked to a libapr in /usr/local.  Tests would not have been valid."; \
	echo "remove library or uninstall offending package"; \
	rpm -qf `ldd test/testall | perl -lane 'print $F[2] if ($F[2] =~ m{^/usr/local});' | grep -v apr`; \
	exit 1; \
fi
if ldd test/testall | perl -lane 'print $F[2] if ($F[2] =~ m{/usr/lib});' | grep expat; then \
	echo "testall is not linked to the libexpat in /usr/lib.  Tests would not have been valid."; \
	echo "Remove the library or uninstall offending package"; \
	rpm -qf `ldd test/testall | perl -lane 'print $F[2] if ($F[2] =~ m{/usr/lib});' | grep expat`; \
	exit 1; \
fi
( cd test && ./testall -q ) || exit 1

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc CHANGES LICENSE NOTICE
%dir %{_libdir}/apr-util-%{apuver}
%{_libdir}/libaprutil-%{apuver}.so.*

%files devel
%defattr(-,root,root,-)
%{_bindir}/apu-%{apuver}-config
%{_libdir}/libaprutil-%{apuver}.*a
%{_libdir}/libaprutil-%{apuver}.so
%{_includedir}/apr-%{apuver}/*.h
%{_libdir}/pkgconfig/*.pc

%files pgsql
%defattr(-,root,root,-)
%{_libdir}/apr-util-%{apuver}/apr_dbd_pgsql*

%files docs
%doc --parents html

%changelog
* Thu Sep 18 2012 Garick Hamlin <ghamlin@redhat.com> - 1.3.12-14
- bump to 1.4.1 for apache-2.2.23
* Thu Sep  8 2011 Garick Hamlin <ghamlin@redhat.com> - 1.3.12-14
- Fixed ldap support.
- Broke pgsql support into a submodule.
- Broke ldap support into a submodule.
* Thu Sep  8 2011 Garick Hamlin <ghamlin@redhat.com> - 1.3.12-12
- Had some problems with tests added some checks to ldd of testall
  to catch some signs of a bad rpmbuild envoronment.
* Wed Sep  7 2011 Garick Hamlin <ghamlin@redhat.com> - 1.3.12-12
- Delete a lot of old patches move to latest tarball.

